<template>
  <div
    @mousemove="extendSession"
    @touchstart="extendSession"
    @keypress="extendSession">
    <div
      id="welcomemsg"
      class="fadein">Welcome {{ authenticatedAccount.name }}! What would you like to do?</div>
    <div id="buttoncontainer">
      <ul
        class="buttonlist fadein"
        style="display: block;">
        <balance-modal :account-id="authenticatedAccount.accountId"/>
        <rewards-modal
          :session="authenticatedAccount.session"
          :account-id="authenticatedAccount.accountId"
          :completed-reward="authenticatedAccount.completed_reward"
          @signed-up="signedUp" />
        <story-modal
          :session="authenticatedAccount.session"
          :account-id="authenticatedAccount.accountId" />
        <suggestion-modal
          :session="authenticatedAccount.session"
          :account-id="authenticatedAccount.accountId"/>
      </ul>
      <ul
        style="float: right; display: block;"
        class="buttonlist fadein">
        <survey-modal
          :session="authenticatedAccount.session"
          :account-id="authenticatedAccount.accountId"
          :completed-survey="authenticatedAccount.completed_survey"
          :account="authenticatedAccount"/>
        <shopping-modal
          :account="authenticatedAccount"
          @refresh-account="refreshAccount"/>
        <like-modal
          :session="authenticatedAccount.session"
          :account-id="authenticatedAccount.accountId"
          :completed-vote="authenticatedAccount.completed_vote"
          @refresh-account="refreshAccount" />
        <logout-modal @logout="logout"/>
        <timeout-modal
          v-if="showModal"
          :show-modal="showModal"
          @logout="logout"
          @extend-session="extendSession" />
      </ul>
      <div class="clear"/>
    </div>
  </div>
</template>

<script>
import BalanceModal from "./CheckBalance.vue";
import RewardsModal from "./RewardsSignUp.vue";
import StoryModal from "./SubmitStory.vue";
import SurveyModal from "./Survey.vue";
import LikeModal from "./Like.vue";
import LogoutModal from "./Logout.vue";
import ShoppingModal from "./Shopping.vue";
import SuggestionModal from "./Suggestion.vue";
import TimeoutModal from "./Timeout.vue";


export default {
  components: {
    BalanceModal,
    RewardsModal,
    StoryModal,
    SurveyModal,
    LikeModal,
    LogoutModal,
    ShoppingModal,
    SuggestionModal,
    TimeoutModal,
  },
  props: {
    authenticatedAccount: Object
  },
  data() {
    return {
      intervalID: "",
      showModal: false
    };
  },
  mounted: function () {
    this.showTimeoutModal();
  },
  destroyed: function () {
    clearInterval(this.intervalID);
  },
  methods: {
    logout() {
      this.$emit("logout");
      this.showModal = false;
    },
    signedUp() {
      this.$emit("signed-up");
    },
    refreshAccount() {
      this.$emit("refresh-account");
    },
    showTimeoutModal() {
      this.intervalID = setInterval(() => {
        this.showModal = true;
      }, 25000);
    },
    extendSession() {
      console.log('extending');
      clearInterval(this.intervalID);
      this.showModal = false;
      this.intervalID = setInterval(() => {
        this.showModal = true;
      }, 25000);
    }
  },

};
</script>